# -*- coding: utf-8 -*-
#
# Copyright (c) 2018, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#

from __future__ import absolute_import, division, print_function
from hlm.public.license_information import _add_used_license, _get_used_licenses, _get_used_licenses_formatted
from hlm.public.license_paths import _add_license_path, _add_license_module_path, _get_extra_license_paths

from hlm.__version__ import __version_info__, __version__


def hostid():
    """
    Build the unique host id used to identify a client for license unlocking.
    
    Returns:
        str: the hexlified host id
    """
    
    import hlm.public.util
    
    return hlm.public.util.get_hostid()


def add_used_license(license_data):
    """
    Add a used license to the inventory. This method is thread safe.
    
    Args:
        license_data (dict): license data to be put into the used license data inventory.
    """
    return _add_used_license(license_data)


def get_used_licenses():
    """
    Get used licenses. This method is thread safe.
    
    Returns:
        dict: a deep copy of the used licenses inventory.
    """
    return _get_used_licenses()


def get_used_licenses_formatted():
    """
    Get used licenses in a human readable way. This method is thread safe.
    
    Returns:
        list of str: the human readable information about the currently used licenses.
    """
    return _get_used_licenses_formatted()


def get_used_licenses_formatted_html():
    licenses = get_used_licenses_formatted()

    ret = ""

    if len(licenses):
        ret = "<br/><br/>License information:<br/>\n"
        for lic in licenses:
            ret += lic + "<br/>\n"

    return ret


def add_license_path(path, pattern="*.txt"):
    """
    Add a license path that will be searched when unlocking products.
    
    Args:
        path (str): a path that will be searched for licenses matching ``pattern``
        pattern (str): a file pattern that may contain wildcard.
    """
    return _add_license_path(path, pattern)


def add_license_module_path(module, pattern="*.txt"):
    """
    Add a license module path that will be searched when unlocking products.
    
    Args:
        module (str): an importable module path that will be searched for licenses matching ``pattern``
        pattern (str): a file pattern that may contain wildcard.
    """
    return _add_license_module_path(module, pattern)


def get_extra_license_paths():
    """
    Get extra license paths added by the user.
    
    Returns:
        list of str: the list of license paths added by the user.
    """
    return _get_extra_license_paths()
